Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig

9 from .core import (

10 all_annotations,

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_into,

15 load_into_class,

16 load_into_instance,

17)

18 from .postpone import postpone

19 from .singleton import Singleton, SingletonMeta

20

21 __all__ = [

22 # cls

23 "TypedConfig",

24 # singleton

25 "Singleton",

26 "SingletonMeta",

27 # core

28 "all_annotations",

29 "check_and_convert_data",

30 "convert_config",

31 "ensure_types",

32 "load_into",

33 "load_into_class",

34 "load_into_instance",

35 # postpone

36 "postpone",

37]